/*
 * Project: Examples for GJA course
 * Authors: Ing. Jan Kouřil
 *          Ing. Jaroslav Dytrych idytrych@fit.vutbr.cz
 * File: Test.java
 * Description: Example Jersey application with using JAXB client
 */

/**
 * @file Test.java
 *
 * @brief Example Jersey application with using JAXB client
 */

/**
 * @package cz.vutbr.fit.knot.gja.JJB.client
 * 
 * @brief Example Jersey application with using JAXB client
 */
package cz.vutbr.fit.knot.gja.JJB.client;

import java.net.URI;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.WebTarget;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.UriBuilder;

/**
 * Example Jersey application with using JAXB client
 */
public class Test {
  
  /**
   * Main method
   * 
   * @param args Command line arguments
   */
  public static void main(String[] args) {
    
    Client client = ClientBuilder.newBuilder().build();
    WebTarget target = client.target(getBaseURI()).path("rest").path("todo");
    
    // Get XML
    System.out.println(target.request(MediaType.TEXT_XML).get(String.class));
    
    // Get JSON for application
    // In GlassFish 4.1.1 fails https://github.com/IQSS/dataverse/issues/2628
    // Read:
    // https://stackoverflow.com/questions/33722764/glassfish-error-when-producing-json
    // https://stackoverflow.com/questions/31275480/glassfish-4-rest-xml-working-json-error
    // Fix: In glassfish-4.1.1/glassfish/modules/ replace jackson-annotations.jar, 
    // jackson-core.jar, jackson-databind.jar, jackson-jaxrs-base.jar, 
    // jackson-jaxrs-json-provider.jar and jackson-module-jaxb-annotations.jar 
    // with newer versions from Maven repository (tested with 2.9.1). 
    // In glassfish-4.1.1/glassfish/modules/ replace org.eclipse.persistence.antlr.jar, 
    // org.eclipse.persistence.asm.jar, org.eclipse.persistence.core.jar, 
    // org.eclipse.persistence.dbws.jar, org.eclipse.persistence.jpa.jpql.jar, 
    // org.eclipse.persistence.jpa.modelgen.processor.jar, org.eclipse.persistence.jpa.jar, 
    // org.eclipse.persistence.moxy.jar and  org.eclipse.persistence.oracle.jar 
    // with newer versions from Maven repository (tested with 2.7.0). 
    // Delete directory glassfish-4.1.1/glassfish/domains/domain1/osgi-cache/felix
    System.out.println(target.request(MediaType.APPLICATION_JSON).get(String.class));
    
    // Get XML for application
    System.out.println(target.request(MediaType.APPLICATION_XML).get(String.class));
  }

  /**
   * Gets server base URI
   * 
   * @return Returns server base URI
   */
  private static URI getBaseURI() {
    return UriBuilder.fromUri("http://localhost:8080/JerseyJAXB").build();
  }
} 
